@@ -183,10 +183,10 @@ class Interaction:
     """A single interaction with the target app."""
 
     request: Request = attr.ib()
-    response: Response = attr.ib()
     status: Status = attr.ib()
-    elapsed: float = attr.ib()
     id: str = attr.ib(factory=(lambda: str(uuid4())))
+    response: Optional[Response] = attr.ib(default=None)
+    elapsed: Optional[float] = attr.ib(default=None)
     name: Optional[str] = attr.ib(factory=str)
     recorded_at: str = attr.ib(factory=lambda: datetime.datetime.now().isoformat())
 
@@ -201,6 +201,13 @@ class Interaction:
             elapsed=response.elapsed.total_seconds() * 1000,
         )
 
+    @classmethod
+    def from_errored_request(cls, request: requests.PreparedRequest) -> "Interaction":
+        return cls(
+            request=Request.from_prepared_request(request),
+            status=Status.error,
+        )
+
 
 class StepRecordType(Enum):
     assertion = "assertion"
@@ -389,12 +396,12 @@ class SerializedAssertionResult:
 @attr.s(slots=True)
 class SerializedInteraction:
     request: Request = attr.ib()
-    response: Response = attr.ib()
     status: str = attr.ib()
-    elapsed: float = attr.ib()
     recorded_at: str = attr.ib()
     curl_code: str = attr.ib()
-    name: Optional[str] = attr.ib()
+    name: Optional[str] = attr.ib(factory=str)
+    response: Optional[Response] = attr.ib(default=None)
+    elapsed: Optional[float] = attr.ib(default=None)
 
     @classmethod
     def from_interaction(cls, interaction: Interaction) -> "SerializedInteraction":
