@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-class ParamType(Enum):
+class ParamType(str, Enum):
     """Resulting status of some action."""
 
     body = "body"
